==> ui-list-10.15.2.tgz: package/es/List/__new-tests__/List.test.js <==
var _List, _List2, _List3, _List4;
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2015 - present Instructure, Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

import React from 'react';
import '@testing-library/jest-dom';
import { render, screen } from '@testing-library/react';
import { vi } from 'vitest';
import { List } from '../index';
import { runAxeCheck } from '@instructure/ui-axe-check';
describe('<List />', () => {
  let consoleWarningMock;
  let consoleErrorMock;
  beforeEach(() => {
    // Mocking console to prevent test output pollution and expect for messages
    consoleWarningMock = vi.spyOn(console, 'warn').mockImplementation(() => {});
    consoleErrorMock = vi.spyOn(console, 'error').mockImplementation(() => {});
  });
  afterEach(() => {
    consoleWarningMock.mockRestore();
    consoleErrorMock.mockRestore();
  });
  it('should render list items and filter out null/falsy children', async () => {
    render(_List || (_List = /*#__PURE__*/React.createElement(List, null, /*#__PURE__*/React.createElement(List.Item, null, "List item 1"), /*#__PURE__*/React.createElement(List.Item, null, "List item 2"), /*#__PURE__*/React.createElement(List.Item, null, "List item 3"), /*#__PURE__*/React.createElement(List.Item, null, "List item 4"), null, false)));
    const listItems = screen.getAllByRole('listitem');
    expect(listItems.length).toEqual(4);
  });
  it('should warn when itemSpacing is set when delimiter is set to anything other than none', async () => {
    render(_List2 || (_List2 = /*#__PURE__*/React.createElement(List, {
      delimiter: "dashed",
      itemSpacing: "large"
    }, /*#__PURE__*/React.createElement(List.Item, null, "List item 1"), /*#__PURE__*/React.createElement(List.Item, null, "List item 2"), /*#__PURE__*/React.createElement(List.Item, null, "List item 3"), /*#__PURE__*/React.createElement(List.Item, null, "List item 4"))));
    const warning = `Warning: [List] \`itemSpacing\` has no effect inside Lists with the \`delimiter\` prop set to anything other than \`none\`.`;
    expect(consoleErrorMock.mock.calls[0][0]).toBe(warning);
  });
  it('should render an ordered list', async () => {
    render(_List3 || (_List3 = /*#__PURE__*/React.createElement(List, {
      as: "ol"
    }, /*#__PURE__*/React.createElement(List.Item, null, "List item 1"), /*#__PURE__*/React.createElement(List.Item, null, "List item 2"), /*#__PURE__*/React.createElement(List.Item, null, "List item 3"), /*#__PURE__*/React.createElement(List.Item, null, "List item 4"))));
    const list = screen.getByRole('list');
    expect(list.tagName).toBe('OL');
  });
  it('should meet a11y standards', async () => {
    const _render = render(_List4 || (_List4 = /*#__PURE__*/React.createElement(List, null, /*#__PURE__*/React.createElement(List.Item, null, "List item 1"), /*#__PURE__*/React.createElement(List.Item, null, "List item 2"), /*#__PURE__*/React.createElement(List.Item, null, "List item 3"), /*#__PURE__*/React.createElement(List.Item, null, "List item 4")))),
      container = _render.container;
    const axeCheck = await runAxeCheck(container);
    expect(axeCheck).toBe(true);
  });
});

==> ui-list-10.19.1.tgz: package/es/List/__new-tests__/List.test.js <==
var _List, _List2, _List3, _List4;
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2015 - present Instructure, Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

import '@testing-library/jest-dom';
import { render, screen } from '@testing-library/react';
import { vi } from 'vitest';
import { List } from '../index';
import { runAxeCheck } from '@instructure/ui-axe-check';
import { jsx as _jsx, jsxs as _jsxs } from "@emotion/react/jsx-runtime";
describe('<List />', () => {
  let consoleWarningMock;
  let consoleErrorMock;
  beforeEach(() => {
    // Mocking console to prevent test output pollution and expect for messages
    consoleWarningMock = vi.spyOn(console, 'warn').mockImplementation(() => {});
    consoleErrorMock = vi.spyOn(console, 'error').mockImplementation(() => {});
  });
  afterEach(() => {
    consoleWarningMock.mockRestore();
    consoleErrorMock.mockRestore();
  });
  it('should render list items and filter out null/falsy children', async () => {
    render(_List || (_List = _jsxs(List, {
      children: [_jsx(List.Item, {
        children: "List item 1"
      }), _jsx(List.Item, {
        children: "List item 2"
      }), _jsx(List.Item, {
        children: "List item 3"
      }), _jsx(List.Item, {
        children: "List item 4"
      }), null, false]
    })));
    const listItems = screen.getAllByRole('listitem');
    expect(listItems.length).toEqual(4);
  });
  it('should warn when itemSpacing is set when delimiter is set to anything other than none', async () => {
    render(_List2 || (_List2 = _jsxs(List, {
      delimiter: "dashed",
      itemSpacing: "large",
      children: [_jsx(List.Item, {
        children: "List item 1"
      }), _jsx(List.Item, {
        children: "List item 2"
      }), _jsx(List.Item, {
        children: "List item 3"
      }), _jsx(List.Item, {
        children: "List item 4"
      })]
    })));
    const warning = `Warning: [List] \`itemSpacing\` has no effect inside Lists with the \`delimiter\` prop set to anything other than \`none\`.`;
    expect(consoleErrorMock.mock.calls[0][0]).toBe(warning);
  });
  it('should render an ordered list', async () => {
    render(_List3 || (_List3 = _jsxs(List, {
      as: "ol",
      children: [_jsx(List.Item, {
        children: "List item 1"
      }), _jsx(List.Item, {
        children: "List item 2"
      }), _jsx(List.Item, {
        children: "List item 3"
      }), _jsx(List.Item, {
        children: "List item 4"
      })]
    })));
    const list = screen.getByRole('list');
    expect(list.tagName).toBe('OL');
  });
  it('should meet a11y standards', async () => {
    const _render = render(_List4 || (_List4 = _jsxs(List, {
        children: [_jsx(List.Item, {
          children: "List item 1"
        }), _jsx(List.Item, {
          children: "List item 2"
        }), _jsx(List.Item, {
          children: "List item 3"
        }), _jsx(List.Item, {
          children: "List item 4"
        })]
      }))),
      container = _render.container;
    const axeCheck = await runAxeCheck(container);
    expect(axeCheck).toBe(true);
  });
});
